@@ -38,6 +38,7 @@
 #include "as-content-rating.h"
 #include "as-launchable.h"
 #include "as-relation.h"
+#include "as-agreement.h"
 
 G_BEGIN_DECLS
 
@@ -70,6 +71,7 @@ struct _AsComponentClass
  * @AS_COMPONENT_KIND_FIRMWARE:		Firmware
  * @AS_COMPONENT_KIND_DRIVER:		A driver
  * @AS_COMPONENT_KIND_LOCALIZATION:	Software localization (usually l10n resources)
+ * @AS_COMPONENT_KIND_REPOSITORY:	A remote software or data source
  *
  * The type of an #AsComponent.
  **/
@@ -87,6 +89,7 @@ typedef enum  {
 	AS_COMPONENT_KIND_DRIVER,
 	AS_COMPONENT_KIND_LOCALIZATION,
 	AS_COMPONENT_KIND_SERVICE,
+	AS_COMPONENT_KIND_REPOSITORY,
 	/*< private >*/
 	AS_COMPONENT_KIND_LAST
 } AsComponentKind;
@@ -101,6 +104,7 @@ AsComponentKind		as_component_kind_from_string (const gchar *kind_str);
  * @AS_MERGE_KIND_NONE:		No merge is happening.
  * @AS_MERGE_KIND_REPLACE:	Merge replacing data of target.
  * @AS_MERGE_KIND_APPEND:	Merge appending data to target.
+ * @AS_MERGE_KIND_REMOVE_COMPONENT: Remove the entire component if it matches.
  *
  * Defines how #AsComponent data should be merged if the component is
  * set for merge.
@@ -109,6 +113,7 @@ typedef enum  {
 	AS_MERGE_KIND_NONE,
 	AS_MERGE_KIND_REPLACE,
 	AS_MERGE_KIND_APPEND,
+	AS_MERGE_KIND_REMOVE_COMPONENT,
 	/*< private >*/
 	AS_MERGE_KIND_LAST
 } AsMergeKind;
@@ -313,7 +318,7 @@ gboolean		as_component_is_valid (AsComponent *cpt);
 gchar			*as_component_to_string (AsComponent *cpt);
 
 GHashTable		*as_component_get_custom (AsComponent *cpt);
-gchar			*as_component_get_custom_value (AsComponent *cpt,
+const gchar		*as_component_get_custom_value (AsComponent *cpt,
 							const gchar *key);
 gboolean		as_component_insert_custom_value (AsComponent *cpt,
 							  const gchar *key,
@@ -328,7 +333,12 @@ void			as_component_add_content_rating (AsComponent *cpt,
 GPtrArray		*as_component_get_recommends (AsComponent *cpt);
 GPtrArray		*as_component_get_requires (AsComponent *cpt);
 void			as_component_add_relation (AsComponent *cpt,
-							AsRelation *relation);
+						   AsRelation *relation);
+
+void			as_component_add_agreement (AsComponent *cpt,
+						    AsAgreement *agreement);
+AsAgreement		*as_component_get_agreement_by_kind (AsComponent *cpt,
+							     AsAgreementKind kind);
 
 
 /* DEPRECATED */
